@@ -377,6 +377,12 @@ class GnomeCanvasItem(_gtk.GtkObject):
 		_gnomeui.gnome_canvas_item_reparent(self._o, new_group._o)
 	def grab_focus(self):
 		_gnomeui.gnome_canvas_item_grab_focus(self._o)
+	def get_bounds(self):
+		return _gnomeui.gnome_canvas_item_get_bounds(self._o)
+	def w2i(self, x, y):
+		return _gnomeui.gnome_canvas_item_w2i(self._o, x, y)
+	def i2w(self, x, y):
+		return _gnomeui.gnome_canvas_item_i2w(self._o, x, y)
 _gtk._name2cls['GnomeCanvasItem'] = GnomeCanvasItem
 
 class GnomeCanvasGroup(GnomeCanvasItem):
