@@ -359,6 +359,21 @@ typedef int (*toargfunc)(gpointer *boxed, PyObject *obj);
 static void (*PyGtk_RegisterBoxed)(GtkType boxed_type,
 				  fromargfunc fromarg, toargfunc toarg);
 
+static PyObject *_register_types() {
+  static gboolean called = FALSE;
+
+  if (!called) {
+    called = TRUE;
+  
+    PyGtk_RegisterBoxed(GTK_TYPE_GDK_IMLIB_IMAGE,
+			imlib_fromarg, imlib_toarg);
+    PyGtk_RegisterBoxed(GTK_TYPE_GNOME_CANVAS_POINTS,
+			points_fromarg, points_toarg);
+  }
+  Py_INCREF(Py_None);
+  return Py_None;
+}
+
 /* we won't worry about all that popt stuff right now ... */
 static PyObject *_wrap_gnome_init(PyObject *self, PyObject *args) {
   char *app_id, *app_version, **argv;
@@ -376,12 +391,9 @@ static PyObject *_wrap_gnome_init(PyObject *self, PyObject *args) {
   gnome_init(app_id, app_version, argc, argv);
   g_free(argv);
 
-  /* some other stuff that needs to be inited */
-  PyGtk_RegisterBoxed(GTK_TYPE_GDK_IMLIB_IMAGE,
-		      imlib_fromarg, imlib_toarg);
-  PyGtk_RegisterBoxed(GTK_TYPE_GNOME_CANVAS_POINTS,
-		      points_fromarg, points_toarg);
+  Py_DECREF(_register_types());
 
+  /* some other stuff that needs to be inited */
   Py_INCREF(Py_None);
   return Py_None;
 }
@@ -481,6 +493,19 @@ static PyObject *_wrap_gnome_app_install_menu_hints(PyObject *self, PyObject *ar
   return Py_None;
 }
 
+static PyObject *_wrap_gnome_canvas_new(PyObject *self, PyObject *args) {
+  GtkWidget *ret;
+
+  if (!PyArg_ParseTuple(args, ":gnome_canvas_new"))
+    return NULL;
+  gtk_widget_push_colormap(gdk_imlib_get_colormap());
+  gtk_widget_push_visual(gdk_imlib_get_visual());
+  ret = gnome_canvas_new();
+  gtk_widget_pop_visual();
+  gtk_widget_pop_colormap();
+  return PyGtk_New((GtkObject *)ret);
+}
+
 static PyObject *_wrap_gnome_canvas_new_aa(PyObject *self, PyObject *args) {
   GtkWidget *ret;
 
@@ -655,6 +680,40 @@ static PyObject *_wrap_gnome_canvas_item_affine_absolute(PyObject *self, PyObjec
   return Py_None;
 }
 
+static PyObject *_wrap_gnome_canvas_item_w2i(PyObject *self, PyObject *args) {
+  PyObject *item;
+  double x, y;
+
+  if (!PyArg_ParseTuple(args, "O!dd:gnome_canvas_item_w2i", PyGtk_Type,
+			&item, &x, &y))
+    return NULL;
+  gnome_canvas_item_w2i(GNOME_CANVAS_ITEM(PyGtk_Get(item)), &x, &y);
+  return Py_BuildValue("(dd)", x, y);
+}
+
+static PyObject *_wrap_gnome_canvas_item_i2w(PyObject *self, PyObject *args) {
+  PyObject *item;
+  double x, y;
+
+  if (!PyArg_ParseTuple(args, "O!dd:gnome_canvas_item_i2w", PyGtk_Type,
+			&item, &x, &y))
+    return NULL;
+  gnome_canvas_item_i2w(GNOME_CANVAS_ITEM(PyGtk_Get(item)), &x, &y);
+  return Py_BuildValue("(dd)", x, y);
+}
+
+static PyObject *_wrap_gnome_canvas_item_get_bounds(PyObject *self, PyObject *args) {
+  PyObject *item;
+  double x1, y1, x2, y2;
+
+  if (!PyArg_ParseTuple(args, "O!:gnome_canvas_item_get_bounds", PyGtk_Type,
+			&item))
+    return NULL;
+  gnome_canvas_item_get_bounds(GNOME_CANVAS_ITEM(PyGtk_Get(item)),
+			       &x1, &y1, &x2, &y2);
+  return Py_BuildValue("(dddd)", x1, y1, x2, y2);
+}
+
 static int read_vector(PyObject *obj, int *argc, char ***argv) {
   int i;
   if (obj == Py_None) {
@@ -788,7 +847,7 @@ static PyObject *_wrap_gnome_client_request_interaction(PyObject *self,
   GnomeDialogType dialog;
   if (!PyArg_ParseTuple(args, "O!OO", PyGtk_Type, &client, &py_dialog, &func))
     return NULL;
-  if (PyGtkEnum_get_value(GTK_TYPE_GNOME_DIALOG_TYPE, py_dialog,(gint*)dialog))
+  if (PyGtkEnum_get_value(GTK_TYPE_GNOME_DIALOG_TYPE,py_dialog,(gint*)&dialog))
     return NULL;
   if (!PyCallable_Check(func)) {
     PyErr_SetString(PyExc_TypeError, "third argument not callbable");
@@ -1308,7 +1367,7 @@ static PyObject *_wrap_gtk_dialog_cauldron(PyObject *self, PyObject *args) {
   data.results = g_new(cauldron_result, data.arg_len);
   result = gtk_dialog_cauldron_parse(title, options, fmt,
 				     (GtkCauldronNextArgCallback)next_arg,
-				     &data);
+				     &data, NULL);
   if (!result) result = "";
   if (data.num_rets == 1)
     ret = PyString_FromString(result);
@@ -1550,12 +1609,14 @@ static PyObject *_wrap_gnome_app_request_password(PyObject *self, PyObject *args
 #include "gnomeuimodule_impl.c"
 
 static PyMethodDef gnomeuiMethods[] = {
+    { "_register_types", _register_types, 1 },
     { "gnome_init", _wrap_gnome_init, 1 },
     { "gnome_about_new", _wrap_gnome_about_new, 1 },
     { "gnome_app_create_menus", _wrap_gnome_app_create_menus, 1 },
     { "gnome_app_create_toolbar", _wrap_gnome_app_create_toolbar, 1 },
     { "gnome_app_insert_menus", _wrap_gnome_app_insert_menus, 1 },
     { "gnome_app_install_menu_hints", _wrap_gnome_app_install_menu_hints, 1 },
+    { "gnome_canvas_new", _wrap_gnome_canvas_new, 1 },
     { "gnome_canvas_new_aa", _wrap_gnome_canvas_new_aa, 1 },
     { "gnome_canvas_get_scroll_region", _wrap_gnome_canvas_get_scroll_region, 1 },
     { "gnome_canvas_get_scroll_offsets", _wrap_gnome_canvas_get_scroll_offsets, 1 },
